==> hlw-core-0.0.2-20250422.075438-9-sources.jar: cn/gtmap/hlw/core/domain/sqxx/model/cqxx/SqxxCqxxSaveModel.java <==
package cn.gtmap.hlw.core.domain.sqxx.model.cqxx;

import cn.gtmap.hlw.core.dto.third.cqzdyxx.dyzm.BdczmThridResultDTO;
import cn.gtmap.hlw.core.dto.third.jzq.JzqxxThirdResultDTO;
import cn.gtmap.hlw.core.model.GxYySqxxTdcbjy;
import cn.gtmap.hlw.core.model.GxYySqxxTdcbjydkxx;
import cn.gtmap.hlw.core.model.GxYySqxxTdxx;
import cn.gtmap.hlw.core.model.GxYySqxxWlzsxx;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;

import java.util.List;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/6/8 13:50
 * @description HtxxManageResultDTO
 */
@Data
public class SqxxCqxxSaveModel {
    /**
     * 受理编号
     */
    private String slbh;
    /**
     * 智慧中枢受理编号
     */
    private String zhzsslbh;
    /**
     * 申请id
     */
    private String sqid;
    /**
     * 申请类型
     */
    private String sqlx;
    private String sqdjlx;
    /**
     * 二次转移申请类型
     */
    private String eczysqdjlx;
    private String fczh;
    private String cqzh;
    private String bdcdyh;
    private String zl;
    private String mj;
    private String sfdy;
    private String sfyg;
    private String sfcf;
    private String bdcdybh;
    private String zsly;
    private String xmid;
    private String fwjg;
    private String fwjgmc;
    private String fwlx;
    private String fwlxmc;
    private String ghyt;
    private String ghytmc;
    private String zcs;
    private String jgsj;
    private String jznf;
    private String fwxz;
    private String szc;
    private String zdyt;
    private String zdytmc;
    private String zdmj;
    private String zdzhqlxz;
    private String zdzhqlxzmc;
    private String tdsyqlx;
    private String tdsyqlxmc;
    private String qydm;
    private String qymc;
    private String djsj;
    private String roomid;
    private String sfyy;
    private String fj;
    private String qllx;
    private String qllxmc;
    private String fwmc;
    private String fwzh;
    private String fwfh;
    private String fttdmj;
    private String sctnmj;
    private String sfblysgg;
    private String zszl;
    private String tdsyqssj;
    private String tdsyjssj;
    private String djyy;
    private String djyymc;
    private String sfsd;
    private String yxmid;
    private String tdzh;
    private String dytdmj;
    private String scftmj;
    private String szxzjd;
    private String bdclx;
    private String bdclxdm;
    private String bdclxmc;
    private String qdjg;
    private String qlslqk;
    private String cqly;
    private String cqlymc;
    private String tdsyqssj2;
    private String tdsyjssj2;
    private String tdsyqssj3;
    private String tdsyjssj3;
    private String syqx;
    private String qjzl;
    private String zdytdm2;
    private String zdytmc2;
    private String zdytdm3;
    private String zdytmc3;
    private String jzqqk;
    private String qsxzdm;
    private String qsxzmc;
    private String glmj;
    private String ccsmj;
    private String qcckmj;
    private String qdfs;
    private String fwdyh;
    private String scqdfwsj;
    private String scqdfwcb;
    private String sfyzdf;
    private String tdsyqr;

    /**
     * 查封信息
     */
    private String bcfr;
    private String cffw;
    private String cfjg;
    private String cfjssj;
    private String cfkssj;
    private String cflx;
    private String cfwh;
    private String cfwj;

    /**
     * 异议信息
     */
    private String yyzmh;
    private String yysx;

    /**
     * 地役信息
     */
    private String dyqnr;
    private String dyqqssj;
    private String dyqjssj;
    private String gydbdcdyh;
    private String xydbdcdyh;
    private String gydqlrmc;
    private String xydqlrmc;

    // 林地信息
    private String lz;
    private String ldsyksqx;
    private String ldsyjsqx;
    private String lb;
    private String xb;
    private String zlnd;
    private String zs;
    private String zysz;
    private String ldsyqxsfyj;
    private String sllbdm;
    private String sllbmc;
    private String sqdj;
    private String xdm;
    private String qy;
    private String zdqlxzdm;
    private String zdqlxzmc;
    private String dzwmj;
    private String fbfmc;
    private String syqmj;
    private String sllmshiyqr;
    private String sllmsyqr;

    /**
     * 申请号
     */
    private String sqh;
    /**
     * 实测建筑面积
     */
    private String jzmj;
    /**
     * 预测建筑面积
     */
    private String ycjzmj;
    /**
     * 规划用途
     */
    private String fwyt;
    /**
     * 规划用途代码
     */
    private String ghytdm;
    /**
     * 总层数
     */
    private String fwzcs;
    /**
     * 所在层
     */
    private String fwszc;
    /**
     * 物理层数
     */
    private String fwsjc;
    private String dycs;
    /**
     * 权利性质代码
     */
    private String qlxzdm;
    /**
     * 宗地用途代码
     */
    private String zdytdm;
    /**
     * 房屋id
     */
    private String fwid;
    /**
     * 证书类型
     */
    private String zslx;
    /**
     * 证明号
     */
    private String zmh;


    /**
     * 权利设定方式dm
     */
    private String qlsdfs;

    /**
     * 小区名称
     */
    private String xqmc;
    /**
     * 栋号
     */
    private String dh;
    /**
     * 房屋面积
     */
    private String fwmj;
    private String tdyt;
    private String tdyt2;
    private String tdyt3;
    /**
     * 更正主体
     */
    private String gzzt;
    /**
     * 房间号
     */
    private String fjh;
    /**
     * 土地使用权开始时间
     */
    private String tdqlqssj;
    /**
     * 土地使用权结束时间
     */
    private String tdqljssj;
    /**
     * 分摊土地面积
     */
    private String tdftmj;

    /**
     * 幢号
     */
    private String zrzh;

    /**
     * 土地坐落
     */
    private String tdzl;
    /**
     * 登记受理编号
     */
    private String djslbh;

    /**
     * 土地信息
     */
    private GxYySqxxTdxx fwtdxx;
    private GxYySqxxTdcbjy tdcbjy;
    private GxYySqxxTdcbjydkxx tdcbjydkxx;

    private List<SqxxCqxxQlrSaveModel> qlrList;
    private List<SqxxCqxxFsssxxSaveModel> fsssxxList;
    private List<SqxxCqxxFwfzxxSaveModel> fwfzxxList;
    private List<BdczmThridResultDTO> dyxxList;
    private GxYySqxxWlzsxx wlzsxx;
    private JzqxxThirdResultDTO jzqxx;


    public void init(SqxxCqxxSaveModel sqxxCqxxSaveModel) {
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getZcs())) {
            sqxxCqxxSaveModel.setFwzcs(sqxxCqxxSaveModel.getZcs());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getSzc())) {
            sqxxCqxxSaveModel.setFwszc(sqxxCqxxSaveModel.getSzc());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getMj())) {
            sqxxCqxxSaveModel.setJzmj(sqxxCqxxSaveModel.getMj());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getGhyt())) {
            sqxxCqxxSaveModel.setGhytdm(sqxxCqxxSaveModel.getGhyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getTdyt()) && StringUtils.isBlank(sqxxCqxxSaveModel.getZdyt())) {
            sqxxCqxxSaveModel.setZdyt(sqxxCqxxSaveModel.getTdyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getZdyt())) {
            sqxxCqxxSaveModel.setZdytdm(sqxxCqxxSaveModel.getZdyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getGhytdm()) && StringUtils.isBlank(sqxxCqxxSaveModel.getFwyt())) {
            sqxxCqxxSaveModel.setFwyt(sqxxCqxxSaveModel.getGhytdm());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getFwyt()) && StringUtils.isBlank(sqxxCqxxSaveModel.getGhytdm())) {
            sqxxCqxxSaveModel.setGhytdm(sqxxCqxxSaveModel.getFwyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getJzmj()) && StringUtils.isBlank(sqxxCqxxSaveModel.getFwmj())) {
            sqxxCqxxSaveModel.setFwmj(sqxxCqxxSaveModel.getJzmj());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getCqzh()) && StringUtils.isBlank(sqxxCqxxSaveModel.getFczh())) {
            sqxxCqxxSaveModel.setFczh(sqxxCqxxSaveModel.getCqzh());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getZdqlxzdm())) {
            sqxxCqxxSaveModel.setZdzhqlxz(sqxxCqxxSaveModel.getZdqlxzdm());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getTdftmj())) {
            sqxxCqxxSaveModel.setFttdmj(sqxxCqxxSaveModel.getTdftmj());
        }
    }
}

==> hlw-core-0.0.2-20250620.121507-62-sources.jar: cn/gtmap/hlw/core/domain/sqxx/model/cqxx/SqxxCqxxSaveModel.java <==
package cn.gtmap.hlw.core.domain.sqxx.model.cqxx;

import cn.gtmap.hlw.core.dto.third.cqzdyxx.dyzm.BdczmThridResultDTO;
import cn.gtmap.hlw.core.dto.third.jzq.JzqxxThirdResultDTO;
import cn.gtmap.hlw.core.model.GxYySqxxTdcbjy;
import cn.gtmap.hlw.core.model.GxYySqxxTdcbjydkxx;
import cn.gtmap.hlw.core.model.GxYySqxxTdxx;
import cn.gtmap.hlw.core.model.GxYySqxxWlzsxx;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;

import java.util.List;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/6/8 13:50
 * @description HtxxManageResultDTO
 */
@Data
public class SqxxCqxxSaveModel {
    /**
     * 受理编号
     */
    private String slbh;
    /**
     * 智慧中枢受理编号
     */
    private String zhzsslbh;
    /**
     * 申请id
     */
    private String sqid;
    /**
     * 申请类型
     */
    private String sqlx;
    private String sqdjlx;
    /**
     * 二次转移申请类型
     */
    private String eczysqdjlx;
    private String fczh;
    private String cqzh;
    private String bdcdyh;
    private String zl;
    private String mj;
    private String sfdy;
    private String sfyg;
    private String sfcf;
    private String bdcdybh;
    private String zsly;
    private String xmid;
    private String fwjg;
    private String fwjgmc;
    private String fwlx;
    private String fwlxmc;
    private String ghyt;
    private String ghytmc;
    private String zcs;
    private String jgsj;
    private String jznf;
    private String fwxz;
    private String szc;
    private String zdyt;
    private String zdytmc;
    private String zdmj;
    private String zdzhqlxz;
    private String zdzhqlxzmc;
    private String tdsyqlx;
    private String tdsyqlxmc;
    private String qydm;
    private String qymc;
    private String djsj;
    private String roomid;
    private String sfyy;
    private String fj;
    private String qllx;
    private String qllxmc;
    private String fwmc;
    private String fwzh;
    private String fwfh;
    private String fttdmj;
    private String sctnmj;
    private String sfblysgg;
    private String zszl;
    private String tdsyqssj;
    private String tdsyjssj;
    private String djyy;
    private String djyymc;
    private String sfsd;
    private String yxmid;
    private String tdzh;
    private String dytdmj;
    private String scftmj;
    private String szxzjd;
    private String bdclx;
    private String bdclxdm;
    private String bdclxmc;
    private String qdjg;
    private String qlslqk;
    private String cqly;
    private String cqlymc;
    private String tdsyqssj2;
    private String tdsyjssj2;
    private String tdsyqssj3;
    private String tdsyjssj3;
    private String syqx;
    private String qjzl;
    private String zdytdm2;
    private String zdytmc2;
    private String zdytdm3;
    private String zdytmc3;
    private String jzqqk;
    private String qsxzdm;
    private String qsxzmc;
    private String glmj;
    private String ccsmj;
    private String qcckmj;
    private String qdfs;
    private String fwdyh;
    private String scqdfwsj;
    private String scqdfwcb;
    private String sfyzdf;
    private String tdsyqr;

    /**
     * 查封信息
     */
    private String bcfr;
    private String cffw;
    private String cfjg;
    private String cfjssj;
    private String cfkssj;
    private String cflx;
    private String cfwh;
    private String cfwj;

    /**
     * 异议信息
     */
    private String yyzmh;
    private String yysx;

    /**
     * 地役信息
     */
    private String dyqnr;
    private String dyqqssj;
    private String dyqjssj;
    private String gydbdcdyh;
    private String xydbdcdyh;
    private String gydqlrmc;
    private String xydqlrmc;

    // 林地信息
    private String lz;
    private String ldsyksqx;
    private String ldsyjsqx;
    private String lb;
    private String xb;
    private String zlnd;
    private String zs;
    private String zysz;
    private String ldsyqxsfyj;
    private String sllbdm;
    private String sllbmc;
    private String sqdj;
    private String xdm;
    private String qy;
    private String zdqlxzdm;
    private String zdqlxzmc;
    private String dzwmj;
    private String fbfmc;
    private String syqmj;
    private String sllmshiyqr;
    private String sllmsyqr;

    /**
     * 申请号
     */
    private String sqh;
    /**
     * 实测建筑面积
     */
    private String jzmj;
    /**
     * 预测建筑面积
     */
    private String ycjzmj;
    /**
     * 规划用途
     */
    private String fwyt;
    /**
     * 规划用途代码
     */
    private String ghytdm;
    /**
     * 总层数
     */
    private String fwzcs;
    /**
     * 所在层
     */
    private String fwszc;
    /**
     * 物理层数
     */
    private String fwsjc;
    private String dycs;
    /**
     * 权利性质代码
     */
    private String qlxzdm;
    /**
     * 宗地用途代码
     */
    private String zdytdm;
    /**
     * 房屋id
     */
    private String fwid;
    /**
     * 证书类型
     */
    private String zslx;
    /**
     * 证明号
     */
    private String zmh;


    /**
     * 权利设定方式dm
     */
    private String qlsdfs;

    /**
     * 小区名称
     */
    private String xqmc;
    /**
     * 栋号
     */
    private String dh;
    /**
     * 房屋面积
     */
    private String fwmj;
    private String tdyt;
    private String tdyt2;
    private String tdyt3;
    /**
     * 更正主体
     */
    private String gzzt;
    /**
     * 房间号
     */
    private String fjh;
    /**
     * 土地使用权开始时间
     */
    private String tdqlqssj;
    /**
     * 土地使用权结束时间
     */
    private String tdqljssj;
    /**
     * 分摊土地面积
     */
    private String tdftmj;

    /**
     * 幢号
     */
    private String zrzh;

    /**
     * 土地坐落
     */
    private String tdzl;
    /**
     * 登记受理编号
     */
    private String djslbh;
    /**
     * 套内建筑面积
     */
    private String tnjzmj;

    /**
     * 土地信息
     */
    private GxYySqxxTdxx fwtdxx;
    private GxYySqxxTdcbjy tdcbjy;
    private GxYySqxxTdcbjydkxx tdcbjydkxx;

    private List<SqxxCqxxQlrSaveModel> qlrList;
    private List<SqxxCqxxFsssxxSaveModel> fsssxxList;
    private List<SqxxCqxxFwfzxxSaveModel> fwfzxxList;
    private List<BdczmThridResultDTO> dyxxList;
    private GxYySqxxWlzsxx wlzsxx;
    private JzqxxThirdResultDTO jzqxx;


    public void init(SqxxCqxxSaveModel sqxxCqxxSaveModel) {
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getZcs())) {
            sqxxCqxxSaveModel.setFwzcs(sqxxCqxxSaveModel.getZcs());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getSzc())) {
            sqxxCqxxSaveModel.setFwszc(sqxxCqxxSaveModel.getSzc());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getMj())) {
            sqxxCqxxSaveModel.setJzmj(sqxxCqxxSaveModel.getMj());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getGhyt())) {
            sqxxCqxxSaveModel.setGhytdm(sqxxCqxxSaveModel.getGhyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getTdyt()) && StringUtils.isBlank(sqxxCqxxSaveModel.getZdyt())) {
            sqxxCqxxSaveModel.setZdyt(sqxxCqxxSaveModel.getTdyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getZdyt())) {
            sqxxCqxxSaveModel.setZdytdm(sqxxCqxxSaveModel.getZdyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getGhytdm()) && StringUtils.isBlank(sqxxCqxxSaveModel.getFwyt())) {
            sqxxCqxxSaveModel.setFwyt(sqxxCqxxSaveModel.getGhytdm());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getFwyt()) && StringUtils.isBlank(sqxxCqxxSaveModel.getGhytdm())) {
            sqxxCqxxSaveModel.setGhytdm(sqxxCqxxSaveModel.getFwyt());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getJzmj()) && StringUtils.isBlank(sqxxCqxxSaveModel.getFwmj())) {
            sqxxCqxxSaveModel.setFwmj(sqxxCqxxSaveModel.getJzmj());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getCqzh()) && StringUtils.isBlank(sqxxCqxxSaveModel.getFczh())) {
            sqxxCqxxSaveModel.setFczh(sqxxCqxxSaveModel.getCqzh());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getZdqlxzdm())) {
            sqxxCqxxSaveModel.setZdzhqlxz(sqxxCqxxSaveModel.getZdqlxzdm());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getTdftmj())) {
            sqxxCqxxSaveModel.setFttdmj(sqxxCqxxSaveModel.getTdftmj());
        }
        if (StringUtils.isBlank(sqxxCqxxSaveModel.getFwsjc()) && StringUtils.isNotBlank(sqxxCqxxSaveModel.getSzc())) {
            sqxxCqxxSaveModel.setFwsjc(sqxxCqxxSaveModel.getSzc());
        }
        if (StringUtils.isNotBlank(sqxxCqxxSaveModel.getTnjzmj()) && StringUtils.isBlank(sqxxCqxxSaveModel.getSctnmj())) {
            sqxxCqxxSaveModel.setSctnmj(sqxxCqxxSaveModel.getTnjzmj());
        }
    }
}
